InputHandler

Struct InputHandler 

pub struct InputHandler { /* private fields */ }
InputHandler class

Attaches keyboard event listeners to a container and converts keyboard events to terminal input data

Implementations

Source

impl InputHandler

pub fn new( ghostty: &Ghostty, container: &HtmlElement, on_data: &Function<fn(JsString) -> Undefined>, on_bell: &Function<fn() -> Undefined>, on_key: Option<&Function<fn(IKeyEvent) -> Undefined>>, custom_key_event_handler: Option<&Function<fn(KeyboardEvent) -> Boolean>>, get_mode: Option<&Function<fn(Number) -> Boolean>>, ) -> InputHandler

Create a new InputHandler

  • ghostty - Ghostty instance (for creating KeyEncoder)
  • container - DOM element to attach listeners to
  • on_data - Callback for terminal data (escape sequences to send to PTY)
  • on_bell - Callback for bell/beep event
  • on_key - Optional callback for raw key events
  • custom_key_event_handler - Optional custom key event handler
  • get_mode - Optional callback to query terminal mode state (for application cursor mode)
Source

impl InputHandler

pub fn set_custom_key_event_handler( &self, handler: &Function<fn(KeyboardEvent) -> Boolean>, )

Set custom key event handler (for runtime updates)

Source

impl InputHandler

pub fn dispose(&self)

Dispose the InputHandler and remove event listeners

Source

impl InputHandler

pub fn is_active(&self) -> bool

Check if handler is disposed

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn as_f64(&self) -> Option<f64>

Returns the f64 value of this JS value if it’s an instance of a number.

If this JS value is not an instance of a number then this returns None.

pub fn is_string(&self) -> bool

Tests whether this JS value is a JS string.

pub fn as_string(&self) -> Option<String>

If this JS value is a string value, this function copies the JS string value into Wasm linear memory, encoded as UTF-8, and returns it as a Rust String.

To avoid the copying and re-encoding, consider the JsString::try_from() function from js-sys instead.

If this JS value is not an instance of a string or if it’s not valid utf-8 then this returns None.

UTF-16 vs UTF-8

JavaScript strings in general are encoded as UTF-16, but Rust strings are encoded as UTF-8. This can cause the Rust string to look a bit different than the JS string sometimes. For more details see the documentation about the str type which contains a few caveats about the encodings.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value of this JS value if it’s an instance of a boolean.

If this JS value is not an instance of a boolean then this returns None.

pub fn is_null(&self) -> bool

Tests whether this JS value is null

pub fn is_undefined(&self) -> bool

Tests whether this JS value is undefined

pub fn is_null_or_undefined(&self) -> bool

Tests whether this JS value is null or undefined

pub fn is_symbol(&self) -> bool

Tests whether the type of this JS value is symbol

pub fn is_object(&self) -> bool

Tests whether typeof self == "object" && self !== null.

pub fn is_array(&self) -> bool

Tests whether this JS value is an instance of Array.

pub fn is_function(&self) -> bool

Tests whether the type of this JS value is function.

pub fn is_bigint(&self) -> bool

Tests whether the type of this JS value is bigint.

pub fn js_typeof(&self) -> JsValue

Applies the unary typeof JS operator on a JsValue.

MDN documentation

pub fn js_in(&self, obj: &JsValue) -> bool

Applies the binary in JS operator on the two JsValues.

MDN documentation

pub fn is_truthy(&self) -> bool

Tests whether the value is “truthy”.

pub fn is_falsy(&self) -> bool

Tests whether the value is “falsy”.

pub fn loose_eq(&self, other: &JsValue) -> bool

Compare two JsValues for equality, using the == operator in JS.

MDN documentation

pub fn bit_not(&self) -> JsValue

Applies the unary ~ JS operator on a JsValue.

MDN documentation

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Applies the binary >>> JS operator on the two JsValues.

MDN documentation

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.

MDN documentation

pub fn pow(&self, rhs: &JsValue) -> JsValue

Applies the binary ** JS operator on the two JsValues.

MDN documentation

pub fn lt(&self, other: &JsValue) -> bool

Applies the binary < JS operator on the two JsValues.

MDN documentation

pub fn le(&self, other: &JsValue) -> bool

Applies the binary <= JS operator on the two JsValues.

MDN documentation

pub fn ge(&self, other: &JsValue) -> bool

Applies the binary >= JS operator on the two JsValues.

MDN documentation

pub fn gt(&self, other: &JsValue) -> bool

Applies the binary > JS operator on the two JsValues.

MDN documentation

pub fn unchecked_into_f64(&self) -> f64

Applies the unary + JS operator on a JsValue. Can throw.

MDN documentation